summaryrefslogtreecommitdiff
path: root/startYACY.sh
diff options
context:
space:
mode:
authororbiter <orbiter@6c8d7289-2bf4-0310-a012-ef5d649a1542>2008-03-16 22:31:54 +0000
committerorbiter <orbiter@6c8d7289-2bf4-0310-a012-ef5d649a1542>2008-03-16 22:31:54 +0000
commit7150b463ff2e6e305e8ffc7012bd615e8a05822d (patch)
tree9a6829c3a3e2e51e8ba4f8b9d5330fbc0b901f22 /startYACY.sh
parent54cb097ea432b254f5ffa7e3d79298c9d3561439 (diff)
changed handling of default values and database paths:
- the default files yacy.init and for the network definition is now moved to the path defaults - the httpProxy.conf is renamed to yacy.conf - the DATA/INDEX/PUBLIC is renamed to the actual network nickname, which should be freeworld or sciencenet more menu entries - added apfelmaennchens alternative search page to the menu - added the new thread dump page to the server log menu point as submenu modifications - modified the thread dump page: sorting by thread type git-svn-id: https://svn.berlios.de/svnroot/repos/yacy/trunk@4575 6c8d7289-2bf4-0310-a012-ef5d649a1542
Diffstat (limited to 'startYACY.sh')
-rwxr-xr-xstartYACY.sh29
1 files changed, 24 insertions, 5 deletions
diff --git a/startYACY.sh b/startYACY.sh
index 2c7293b7b..f8b057402 100755
--- a/startYACY.sh
+++ b/startYACY.sh
@@ -77,24 +77,24 @@ done
#get javastart args
java_args=""
-if [ -f DATA/SETTINGS/httpProxy.conf ]
+if [ -f DATA/SETTINGS/yacy.conf ]
then
# startup memory
for i in Xmx Xms; do
- j="`grep javastart_$i DATA/SETTINGS/httpProxy.conf | sed 's/^[^=]*=//'`";
+ j="`grep javastart_$i DATA/SETTINGS/yacy.conf | sed 's/^[^=]*=//'`";
if [ -n $j ]; then JAVA_ARGS="-$j $JAVA_ARGS"; fi;
done
# Priority
- j="`grep javastart_priority DATA/SETTINGS/httpProxy.conf | sed 's/^[^=]*=//'`";
+ j="`grep javastart_priority DATA/SETTINGS/yacy.conf | sed 's/^[^=]*=//'`";
if [ ! -z "$j" ];then
if [ -n $j ]; then JAVA="nice -n $j $JAVA"; fi;
fi
- PORT="`grep ^port= DATA/SETTINGS/httpProxy.conf | sed 's/^[^=]*=//'`";
+ PORT="`grep ^port= DATA/SETTINGS/yacy.conf | sed 's/^[^=]*=//'`";
-# for i in `grep javastart DATA/SETTINGS/httpProxy.conf`;do
+# for i in `grep javastart DATA/SETTINGS/yacy.conf`;do
# i="${i#javastart_*=}";
# JAVA_ARGS="-$i $JAVA_ARGS";
# done
@@ -102,6 +102,25 @@ else
JAVA_ARGS="-Xmx120m -Xms120m $JAVA_ARGS";
PORT="8080"
fi
+
+if [ -f DATA/SETTINGS/httpProx.conf ]
+then
+ # startup memory
+ for i in Xmx Xms; do
+ j="`grep javastart_$i DATA/SETTINGS/httpProxy.conf | sed 's/^[^=]*=//'`";
+ if [ -n $j ]; then JAVA_ARGS="-$j $JAVA_ARGS"; fi;
+ done
+
+ # Priority
+ j="`grep javastart_priority DATA/SETTINGS/httpProxy.conf | sed 's/^[^=]*=//'`";
+
+ if [ ! -z "$j" ];then
+ if [ -n $j ]; then JAVA="nice -n $j $JAVA"; fi;
+ fi
+
+ PORT="`grep ^port= DATA/SETTINGS/httpProxy.conf | sed 's/^[^=]*=//'`";
+fi
+
#echo "JAVA_ARGS: $JAVA_ARGS"
#echo "JAVA: $JAVA"